pub struct Authenticate;Trait Implementations
Sourceimpl GraphQLQuery for Authenticate
impl GraphQLQuery for Authenticate
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for Authenticate
impl RefUnwindSafe for Authenticate
impl Send for Authenticate
impl Sync for Authenticate
impl Unpin for Authenticate
impl UnsafeUnpin for Authenticate
impl UnwindSafe for Authenticate